==> ui-list-10.15.2.tgz: package/es/InlineList/__examples__/InlineList.examples.js <==
var _InlineList$Item, _InlineList$Item2, _InlineList$Item3;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import React from 'react';
import { InlineList } from '../index';
export default {
  sectionProp: 'size',
  getComponentProps: () => {
    return {
      children: [_InlineList$Item || (_InlineList$Item = /*#__PURE__*/React.createElement(InlineList.Item, {
        key: "1"
      }, "Oranges")), _InlineList$Item2 || (_InlineList$Item2 = /*#__PURE__*/React.createElement(InlineList.Item, {
        key: "2"
      }, "Pineapples")), _InlineList$Item3 || (_InlineList$Item3 = /*#__PURE__*/React.createElement(InlineList.Item, {
        key: "3"
      }, "Bananas"))]
    };
  },
  filter: props => {
    return (
      // itemSpacing has no affect on the list if the delimiter prop is set
      // to anything other than 'none' so filter the others
      props.delimiter !== 'none' && props.itemSpacing !== 'none'
    );
  }
};

==> ui-list-10.19.1.tgz: package/es/InlineList/__examples__/InlineList.examples.js <==
var _InlineList$Item, _InlineList$Item2, _InlineList$Item3;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { InlineList } from '../index';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
export default {
  sectionProp: 'size',
  getComponentProps: () => {
    return {
      children: [_InlineList$Item || (_InlineList$Item = _jsx(InlineList.Item, {
        children: "Oranges"
      }, "1")), _InlineList$Item2 || (_InlineList$Item2 = _jsx(InlineList.Item, {
        children: "Pineapples"
      }, "2")), _InlineList$Item3 || (_InlineList$Item3 = _jsx(InlineList.Item, {
        children: "Bananas"
      }, "3"))]
    };
  },
  filter: props => {
    return (
      // itemSpacing has no affect on the list if the delimiter prop is set
      // to anything other than 'none' so filter the others
      props.delimiter !== 'none' && props.itemSpacing !== 'none'
    );
  }
};
